@@ -1,10 +1,12 @@
-use super::CssWriter;
 use std::{
     fmt::{Result, Write},
     str::from_utf8,
 };
+
 use swc_common::Span;
 
+use super::CssWriter;
+
 pub struct BasicCssWriterConfig<'a> {
     pub indent: &'a str,
 }
@@ -91,9 +93,9 @@ where
                     let b4;
                     let char_as_u8 = char as u8;
 
-                    let bytes = if char_as_u8 > 0x0F {
+                    let bytes = if char_as_u8 > 0x0f {
                         let high = (char_as_u8 >> 4) as usize;
-                        let low = (char_as_u8 & 0x0F) as usize;
+                        let low = (char_as_u8 & 0x0f) as usize;
 
                         b4 = [b'\\', HEX_DIGITS[high], HEX_DIGITS[low], b' '];
 
